@@ -19,18 +19,20 @@ var searchData=
   ['update_16',['update',['../classgko_1_1stop_1_1Criterion.html#a47e22c46eaa742d709dcbf0d26d93e6c',1,'gko::stop::Criterion']]],
   ['updater_17',['Updater',['../classgko_1_1stop_1_1Criterion_1_1Updater.html',1,'gko::stop::Criterion::Updater'],['../classgko_1_1stop_1_1Criterion_1_1Updater.html#aa8356e2fbfaf46cab62d8f8a905ab8bd',1,'gko::stop::Criterion::Updater::Updater()']]],
   ['uppertrs_18',['UpperTrs',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver::UpperTrs&lt; ValueType, IndexType &gt;'],['../classgko_1_1solver_1_1UpperTrs.html#a9fc8a602b284e8923b6a30135c84c437',1,'gko::solver::UpperTrs::UpperTrs(const UpperTrs &amp;)'],['../classgko_1_1solver_1_1UpperTrs.html#a97322e2b1e6bcce67f074f7fc5dd7cd1',1,'gko::solver::UpperTrs::UpperTrs(UpperTrs &amp;&amp;)']]],
-  ['usage_19',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
-  ['use_20of_20macros_20vs_20functions_20',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
-  ['usecomposition_21',['UseComposition',['../classgko_1_1UseComposition.html',1,'gko']]],
-  ['usecomposition_3c_20default_5fprecision_20_3e_22',['UseComposition&lt; default_precision &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
-  ['usecomposition_3c_20valuetype_20_3e_23',['UseComposition&lt; ValueType &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
-  ['user_24',['user',['../namespacegko_1_1log.html#a15f71654c6c4f4defc95f9359343fa27aee11cbb19052e40b07aac0ca060c23ee',1,'gko::log']]],
-  ['user_5frange_25',['user_range',['../classgko_1_1log_1_1ProfilerHook.html#a4d0e1e93d993f5074d60276359faadd8',1,'gko::log::ProfilerHook']]],
-  ['using_20batchcg_20in_20ginkgo_26',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
-  ['using_20cg_20in_20ginkgo_27',['Example: using CG in Ginkgo',['../classgko_1_1LinOpFactory.html#autotoc_md74',1,'']]],
-  ['using_20ctest_28',['Using CTest',['../testing_ginkgo.html#autotoc_md10',1,'']]],
-  ['using_20library_20classes_29',['Using library classes',['../contributing_guidelines.html#autotoc_md22',1,'']]],
-  ['using_20make_20quick_5ftest_30',['Using make quick_test',['../testing_ginkgo.html#autotoc_md9',1,'']]],
-  ['using_20make_20test_31',['Using make test',['../testing_ginkgo.html#autotoc_md8',1,'']]],
-  ['using_20ssget_20to_20fetch_20the_20matrices_32',['2: Using ssget to fetch the matrices',['../benchmarking_ginkgo.html#autotoc_md12',1,'']]]
+  ['uppertrs_3c_20value_5ftype_2c_20index_5ftype_20_3e_19',['UpperTrs&lt; value_type, index_type &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
+  ['uppertrs_3c_20valuetype_2c_20indextype_20_3e_20',['UpperTrs&lt; ValueType, IndexType &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
+  ['usage_21',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
+  ['use_20of_20macros_20vs_20functions_22',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
+  ['usecomposition_23',['UseComposition',['../classgko_1_1UseComposition.html',1,'gko']]],
+  ['usecomposition_3c_20default_5fprecision_20_3e_24',['UseComposition&lt; default_precision &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
+  ['usecomposition_3c_20valuetype_20_3e_25',['UseComposition&lt; ValueType &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
+  ['user_26',['user',['../namespacegko_1_1log.html#a15f71654c6c4f4defc95f9359343fa27aee11cbb19052e40b07aac0ca060c23ee',1,'gko::log']]],
+  ['user_5frange_27',['user_range',['../classgko_1_1log_1_1ProfilerHook.html#a4d0e1e93d993f5074d60276359faadd8',1,'gko::log::ProfilerHook']]],
+  ['using_20batchcg_20in_20ginkgo_28',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
+  ['using_20cg_20in_20ginkgo_29',['Example: using CG in Ginkgo',['../classgko_1_1LinOpFactory.html#autotoc_md74',1,'']]],
+  ['using_20ctest_30',['Using CTest',['../testing_ginkgo.html#autotoc_md10',1,'']]],
+  ['using_20library_20classes_31',['Using library classes',['../contributing_guidelines.html#autotoc_md22',1,'']]],
+  ['using_20make_20quick_5ftest_32',['Using make quick_test',['../testing_ginkgo.html#autotoc_md9',1,'']]],
+  ['using_20make_20test_33',['Using make test',['../testing_ginkgo.html#autotoc_md8',1,'']]],
+  ['using_20ssget_20to_20fetch_20the_20matrices_34',['2: Using ssget to fetch the matrices',['../benchmarking_ginkgo.html#autotoc_md12',1,'']]]
 ];
