@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: "1234567abcdefghijklmnopqrstuvwz~",
   1: "abcdefghijklmnoprstuvwz",
-  2: "g",
+  2: "gs",
   3: "abcdefghijklmnoprstuvwz~",
   4: "abcdefghiklmnoprstu",
   5: "acdefhinprstuv",
