@@ -1,7 +1,7 @@
 var searchData=
 [
   ['accuracy_0',['accuracy',['../structgko_1_1preconditioner_1_1Jacobi_1_1parameters__type.html#ad4fd0de7ce4d390584e947afb6d0ce73',1,'gko::preconditioner::Jacobi::parameters_type']]],
-  ['algorithm_1',['algorithm',['../structgko_1_1solver_1_1LowerTrs_1_1parameters__type.html#a39f01cb27d3a256a2168055079b3a1ce',1,'gko::solver::LowerTrs::parameters_type::algorithm'],['../structgko_1_1solver_1_1UpperTrs_1_1parameters__type.html#ada5bbbcba5a02aa7eb0090b57e4ee5d2',1,'gko::solver::UpperTrs::parameters_type::algorithm']]],
+  ['algorithm_1',['algorithm',['../structgko_1_1factorization_1_1Ic_1_1parameters__type.html#a9c5dca5a13bdd9e8d4a72650ba27b931',1,'gko::factorization::Ic::parameters_type::algorithm'],['../structgko_1_1factorization_1_1Ilu_1_1parameters__type.html#accc8821162d5eab103579d606ca8ff32',1,'gko::factorization::Ilu::parameters_type::algorithm'],['../structgko_1_1solver_1_1LowerTrs_1_1parameters__type.html#a39f01cb27d3a256a2168055079b3a1ce',1,'gko::solver::LowerTrs::parameters_type::algorithm'],['../structgko_1_1solver_1_1UpperTrs_1_1parameters__type.html#ada5bbbcba5a02aa7eb0090b57e4ee5d2',1,'gko::solver::UpperTrs::parameters_type::algorithm']]],
   ['all_5fevents_5fmask_2',['all_events_mask',['../classgko_1_1log_1_1Logger.html#a02534863a2d2f92dfeb2c39038365532',1,'gko::log::Logger']]],
   ['approximate_5fselect_3',['approximate_select',['../structgko_1_1factorization_1_1ParIct_1_1parameters__type.html#a0fbcf399e8eb618f308804c0c98f3751',1,'gko::factorization::ParIct::parameters_type::approximate_select'],['../structgko_1_1factorization_1_1ParIlut_1_1parameters__type.html#a896c2b6e30c3cb0b2e797945b92f26a3',1,'gko::factorization::ParIlut::parameters_type::approximate_select']]]
 ];
